FragmentClassDefinition class

Define a Dart class parsed from GraphQL fragment.

Inheritance
Mixed-in types

Constructors

FragmentClassDefinition({required FragmentName name, required Iterable<ClassProperty> properties})
Instantiate a fragment class definition.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → FragmentName
The definition name.
final
namedProps → Map<String, Object>
no setteroverride
properties → Iterable<ClassProperty>
The properties (fields) of the class.
final
props → List
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited