NamingScheme enum

The naming scheme to be used on generated classes names.

Inheritance
Available extensions

Values

pathedWithTypes → const NamingScheme

Default, where the names of previous types are used as prefix of the next class. This can generate duplication on certain schemas.

pathedWithFields → const NamingScheme

The names of previous fields are used as prefix of the next class.

simple → const NamingScheme

Considers only the actual GraphQL class name. This will probably lead to duplication and an Artemis error unless user uses aliases.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<NamingScheme>
A constant List of the values in this enum, in order of their declaration.